@@ -26,6 +26,7 @@ class FileType(enum.Enum):
     mnist = 6
     MNIST = 7
     processed = 8
+    output = 9
 
 
 def create_training_job(local_train_data, local_test_data, entry_point, inputs_folder, hyper_param):
@@ -50,16 +51,6 @@ def create_training_job(local_train_data, local_test_data, entry_point, inputs_f
         print(f"upladed {entry_point}")
 
     if inputs_folder is not None:
-        ## TODO Zip the files on the folder and upload all.
-        #get_zipfile(inputs_folder,'./mnist')
-        #folder_upload(job_id, inputs_folder)
-        #__upload_one_file(job_id, FileType.Inputs.name, inputs_folder)
-        #list_dirs = os.walk(inputs_folder) 
-        #for root, dirs, files in list_dirs:      
-        #    for f in files: 
-        #        __upload_one_file(job_id, FileType.processed.name, f)
-                         
-        #print(f"upladed {inputs_folder}")
         pass
 
     # put hyper param to Dynamodb through API Gateway
@@ -88,8 +79,32 @@ def folder_upload(jobid, rootDir):
 def get_training_job_status(job_id):
 
     # read status from API Gateay - backed by Dynamodb
+    url = f"{API_GW}/jobs/{job_id}"
+    print(f"getting {url}")
+    response = requests.request("GET", url)
+    print(f"response {response}")
+    response_body = json.loads(response.text)
+    print(response_body[job_id])
+    return response_body[job_id]
 
-    pass
+def get_model(job_id, model):
+    url = f"{API_GW}/s3urld/{job_id}/{FileType.output.name}/{model}"
+    response = requests.get(url, allow_redirects=True)
+
+    response_s3 = requests.get(response.__dict__['_content'])
+    print(f"getting {url}")
+
+    if response.status_code == 200:
+        size = 2**10
+        with open("./model.tar.gz", 'wb') as tar:
+            for chunk in response_s3.iter_content(chunk_size=size):
+                tar.write(chunk)
+        tar.close()
+
+
+
+
+    
 
 def cancel_training_job_status(job_id):
     """
@@ -153,6 +168,8 @@ def __upload_one_file_infolder(job_id, type1, type2, type3, object_name):
 
 if __name__ == "__main__":
     #__upload_one_file("11112222", "mnist/MNIST/processed", "buffer1.txt")
-    create_training_job("training.pt", "test.pt", "buffer1.txt", None, {"epoch":"10"})
+    #create_training_job("training.pt", "test.pt", "buffer1.txt", None, {"epoch":"10"})
     #get_zipfile("./test","./test.zip")
-    #folder_upload("test")
\ No newline at end of file
+    #folder_upload("test")
+    #get_training_job_status("125cddd2-6686-44c2-8e14-1e4fe882ad94")
+    get_model("125cddd2-6686-44c2-8e14-1e4fe882ad94", "model.tar.gz")
\ No newline at end of file
